==> dabstick-radio-0.92.tgz: dabstick-radio-0.92/dabreceiver-V2/backend/mp4processor.h <==
#
#ifndef	MP4PROCESSOR
#define	MP4PROCESSOR
/*
 * 	Handling superframes for DAB+ and delivering
 * 	frames into the ffmpeg or faad decoding library
 */
//
#include	"dab-constants.h"
#include	<stdio.h>
#include	<stdint.h>
#include	"audiosink.h"
#include	"dab_processor.h"
#include	"firecode_checker.h"
#include	"rscodec.h"
#include	<QObject>

//#define	FFMPEG
class	RadioInterface;
#ifdef	FFMPEG
class	ffmpegDecoder;
#else
class	faadDecoder;
#endif

class	mp4Processor : public QObject, public dabProcessor {
Q_OBJECT
public:
			mp4Processor	(RadioInterface *, audioSink *, int16_t);
			~mp4Processor	(void);
	void		addtoFrame	(uint8_t *, int16_t);
private:
	bool		processSuperframe (uint8_t [], int16_t);

	RadioInterface	*myRadioInterface;
	int16_t		superFramesize;
	int16_t		blockFillIndex;
	int16_t		blocksInBuffer;
	int16_t		blockCount;
	int16_t		bitRate;
	uint8_t		*frameBytes;
	uint8_t		**RSMatrix;
	int16_t		RSDims;
	int16_t		au_start	[10];
	int32_t		baudRate;

	int16_t		au_count;
	int16_t		au_errors;
	int16_t		errorRate;
	firecode_checker	fc;
	rscodec		rsDecoder;
	int16_t		aacFrameLength;
	uint8_t		*outVector;

	uint8_t		d_header	[10];

	struct adts_fixed_header {
	        unsigned int syncword           :12;
	        unsigned int id                 :1;
	        unsigned int layer              :2;
	        unsigned int protection_absent  :1;
	        unsigned int profile_objecttype :2;
	        unsigned int sampling_freq_idx  :4;
	        unsigned int private_bit        :1;
	        unsigned int channel_conf       :3;
	        unsigned int original_copy      :1;
	        unsigned int home               :1;
	    } d_fh;

	    struct adts_variable_header {
	        unsigned int copyright_id_bit       :1;
	        unsigned int copyright_id_start     :1;
	        unsigned int aac_frame_length       :13;
	        unsigned int adts_buffer_fullness   :11;
	        unsigned int no_raw_data_blocks     :2;
	    }d_vh;

//
//	and for the aac decoder
#ifdef	FFMPEG
	ffmpegDecoder	*aacDecoder;
#else
	faadDecoder	*aacDecoder;
#endif
	audioSink	*ourSink;
	int16_t		frameCount;
	int16_t		frameErrors;
signals:
	void		show_successRate		(int);
};

#endif

==> dabstick-radio-0.95.tgz: dabstick-radio-0.95/dabreceiver-V2/backend/mp4processor.h <==
#
#ifndef	MP4PROCESSOR
#define	MP4PROCESSOR
/*
 * 	Handling superframes for DAB+ and delivering
 * 	frames into the ffmpeg or faad decoding library
 */
//
#include	"dab-constants.h"
#include	<stdio.h>
#include	<stdint.h>
#include	"audiosink.h"
#include	"dab_processor.h"
#include	"firecode_checker.h"
#include	"rscodec.h"
#include	<QObject>

//#define	FFMPEG
class	RadioInterface;
#ifdef	FFMPEG
class	ffmpegDecoder;
#else
class	faadDecoder;
#endif

class	mp4Processor : public QObject, public dabProcessor {
Q_OBJECT
public:
			mp4Processor	(RadioInterface *,
	                                 audioSink *,
	                                 FILE *,
	                                 int16_t);
			~mp4Processor	(void);
	void		addtoFrame	(uint8_t *, int16_t);
	void		setFile		(FILE *);
private:
	bool		processSuperframe (uint8_t [], int16_t);

	RadioInterface	*myRadioInterface;
	audioSink	*ourSink;
	FILE		*mp4File;
	int16_t		superFramesize;
	int16_t		blockFillIndex;
	int16_t		blocksInBuffer;
	int16_t		blockCount;
	int16_t		bitRate;
	uint8_t		*frameBytes;
	uint8_t		**RSMatrix;
	int16_t		RSDims;
	int16_t		au_start	[10];
	int32_t		baudRate;

	int16_t		au_count;
	int16_t		au_errors;
	int16_t		errorRate;
	firecode_checker	fc;
	rscodec		rsDecoder;
	int16_t		aacFrameLength;
	uint8_t		*outVector;

	uint8_t		d_header	[10];

	struct adts_fixed_header {
	        unsigned int syncword           :12;
	        unsigned int id                 :1;
	        unsigned int layer              :2;
	        unsigned int protection_absent  :1;
	        unsigned int profile_objecttype :2;
	        unsigned int sampling_freq_idx  :4;
	        unsigned int private_bit        :1;
	        unsigned int channel_conf       :3;
	        unsigned int original_copy      :1;
	        unsigned int home               :1;
	    } d_fh;

	    struct adts_variable_header {
	        unsigned int copyright_id_bit       :1;
	        unsigned int copyright_id_start     :1;
	        unsigned int aac_frame_length       :13;
	        unsigned int adts_buffer_fullness   :11;
	        unsigned int no_raw_data_blocks     :2;
	    }d_vh;

//
//	and for the aac decoder
#ifdef	FFMPEG
	ffmpegDecoder	*aacDecoder;
#else
	faadDecoder	*aacDecoder;
#endif
	int16_t		frameCount;
	int16_t		frameErrors;
signals:
	void		show_successRate		(int);
};

#endif
